@@ -24,11 +24,11 @@ _SCORE_TYPE_CHOICES = (
 SCORE_TYPES = dict((value, key) for key, value in _SCORE_TYPE_CHOICES)
 
 class Vote(models.Model):
-    content_type = models.ForeignKey(ContentType, related_name="votes")
+    content_type = models.ForeignKey(ContentType, related_name="updown_votes")
     object_id = models.PositiveIntegerField()
     key = models.CharField(max_length=32)
     score = models.SmallIntegerField(choices=_SCORE_TYPE_CHOICES)
-    user = models.ForeignKey(User, blank=True, null=True, related_name="votes")
+    user = models.ForeignKey(User, blank=True, null=True, related_name="updown_votes")
     ip_address = models.IPAddressField()
     date_added = models.DateTimeField(default=datetime.datetime.now, editable=False)
     date_changed = models.DateTimeField(default=datetime.datetime.now, editable=False)
